%
% ------------------------------------------------------------------
% function [q2] = FT_q_ABCD_q(M, q1, n1, n2)
%
% Function for that transforms a gaussian beam parameter
% by an ABCD matrix as follows:
% 
%                      A q1/n1 + B            (A B)
% Computes q2 = n2*  --------------- with M = (C D)
%                      C q1/n1 + D
%
%   M: 2x2 (or 2x2x2) ABCD (transformation) matrix
%   q1: input Gaussian beam parameter (complex number)
%   n1: index of refrection where beam is given by q1
%   n2: index of refrection where beam is given by q2
%
%   q2: output Gaussian beam parameter (complex number)
%
% Part of the SimTools package
% A. Freise 11.07.2006 adf@star.sr.bham.ac.uk
% ------------------------------------------------------------------
%

% Description: Transforms a Gaussian beam parameter by an ABCD matrix
% Keywords: transform, Gaussian, parameter, q

function [q2] = FT_q_ABCD_q(Min, q1, n1, n2)

  baseid='q_ABCD_q';
  
  
  q=q1/n1;
  q2= n2*((Min(1,1)*q + Min(1,2)) / ( Min(2,1)*q + Min(2,2)));
