%--------------------------------------------------------------------------
% function [map] = FT_read_MetroPro_map(filename,type,field)
%
% A function for Matlab which outputs mirror surface (or other) data in the
% standard map structure.  Requires Hiro Yamamoto's LoadMetroProData Matlab
% function.
%
% filename:     Raw map data file.
% type:         Type of data
%               0: surface height data
%               1: absorption data
%               2: reflectivity data
% field:        Integer defining which light fields are affected.
%               0: both (reflected and transmitted)
%               1: reflected only
%               2: transmitted only
%
% map:          Returned mirror data in map structure (see
%               FT_new_surface_map.m).
%
% Charlotte Bond    28.03.2014
%--------------------------------------------------------------------------
%

function [map] = FT_read_MetroPro_map(filename,type,field)

    % Read in data from raw file
    [z,x,y] = LoadMetroProData(filename);

    [rows,cols] = size(z);
    x0 = (cols+1)/2;
    y0 = (rows+1)/2;
    xstep = x(2)-x(1);
    ystep = y(2)-y(1);
    scaling = 1;
    
    mapname = FT_remove_file_extension(filename);
    
    % Write data into map structure
    map = FT_new_surface_map(mapname,z,type,field,x0,y0,xstep,ystep,scaling);


end